@@ -6,15 +6,16 @@ Type annotations for amp service client paginators.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
 
-    from mypy_boto3_amp import PrometheusServiceClient
+    from mypy_boto3_amp.client import PrometheusServiceClient
     from mypy_boto3_amp.paginator import (
         ListRuleGroupsNamespacesPaginator,
         ListWorkspacesPaginator,
     )
 
-    client: PrometheusServiceClient = boto3.client("amp")
+    session = Session()
+    client: PrometheusServiceClient = session.client("amp")
 
     list_rule_groups_namespaces_paginator: ListRuleGroupsNamespacesPaginator = client.get_paginator("list_rule_groups_namespaces")
     list_workspaces_paginator: ListWorkspacesPaginator = client.get_paginator("list_workspaces")
@@ -46,7 +47,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class ListRuleGroupsNamespacesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/amp.html#PrometheusService.Paginator.ListRuleGroupsNamespaces)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/amp.html#PrometheusService.Paginator.ListRuleGroupsNamespaces)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amp/paginators.html#listrulegroupsnamespacespaginator)
     """
 
@@ -54,14 +55,14 @@ class ListRuleGroupsNamespacesPaginator(Boto3Paginator):
         self, *, workspaceId: str, name: str = ..., PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListRuleGroupsNamespacesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/amp.html#PrometheusService.Paginator.ListRuleGroupsNamespaces.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/amp.html#PrometheusService.Paginator.ListRuleGroupsNamespaces.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amp/paginators.html#listrulegroupsnamespacespaginator)
         """
 
 
 class ListWorkspacesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/amp.html#PrometheusService.Paginator.ListWorkspaces)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/amp.html#PrometheusService.Paginator.ListWorkspaces)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amp/paginators.html#listworkspacespaginator)
     """
 
@@ -69,6 +70,6 @@ class ListWorkspacesPaginator(Boto3Paginator):
         self, *, alias: str = ..., PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListWorkspacesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/amp.html#PrometheusService.Paginator.ListWorkspaces.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/amp.html#PrometheusService.Paginator.ListWorkspaces.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amp/paginators.html#listworkspacespaginator)
         """
