@@ -16,6 +16,7 @@ from datetime import datetime
 from typing import IO, Dict, List, Mapping, Sequence, Union
 
 from botocore.response import StreamingBody
+from typing_extensions import NotRequired
 
 from .literals import (
     AlertManagerDefinitionStatusCodeType,
@@ -81,49 +82,22 @@ AlertManagerDefinitionDescriptionTypeDef = TypedDict(
     },
 )
 
-_RequiredAlertManagerDefinitionStatusTypeDef = TypedDict(
-    "_RequiredAlertManagerDefinitionStatusTypeDef",
+AlertManagerDefinitionStatusTypeDef = TypedDict(
+    "AlertManagerDefinitionStatusTypeDef",
     {
         "statusCode": AlertManagerDefinitionStatusCodeType,
+        "statusReason": NotRequired[str],
     },
 )
-_OptionalAlertManagerDefinitionStatusTypeDef = TypedDict(
-    "_OptionalAlertManagerDefinitionStatusTypeDef",
-    {
-        "statusReason": str,
-    },
-    total=False,
-)
 
-
-class AlertManagerDefinitionStatusTypeDef(
-    _RequiredAlertManagerDefinitionStatusTypeDef, _OptionalAlertManagerDefinitionStatusTypeDef
-):
-    pass
-
-
-_RequiredCreateAlertManagerDefinitionRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateAlertManagerDefinitionRequestRequestTypeDef",
+CreateAlertManagerDefinitionRequestRequestTypeDef = TypedDict(
+    "CreateAlertManagerDefinitionRequestRequestTypeDef",
     {
         "data": Union[bytes, IO[bytes], StreamingBody],
         "workspaceId": str,
+        "clientToken": NotRequired[str],
     },
 )
-_OptionalCreateAlertManagerDefinitionRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateAlertManagerDefinitionRequestRequestTypeDef",
-    {
-        "clientToken": str,
-    },
-    total=False,
-)
-
-
-class CreateAlertManagerDefinitionRequestRequestTypeDef(
-    _RequiredCreateAlertManagerDefinitionRequestRequestTypeDef,
-    _OptionalCreateAlertManagerDefinitionRequestRequestTypeDef,
-):
-    pass
-
 
 CreateAlertManagerDefinitionResponseTypeDef = TypedDict(
     "CreateAlertManagerDefinitionResponseTypeDef",
@@ -133,30 +107,16 @@ CreateAlertManagerDefinitionResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateRuleGroupsNamespaceRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateRuleGroupsNamespaceRequestRequestTypeDef",
+CreateRuleGroupsNamespaceRequestRequestTypeDef = TypedDict(
+    "CreateRuleGroupsNamespaceRequestRequestTypeDef",
     {
         "data": Union[bytes, IO[bytes], StreamingBody],
         "name": str,
         "workspaceId": str,
+        "clientToken": NotRequired[str],
+        "tags": NotRequired[Mapping[str, str]],
     },
 )
-_OptionalCreateRuleGroupsNamespaceRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateRuleGroupsNamespaceRequestRequestTypeDef",
-    {
-        "clientToken": str,
-        "tags": Mapping[str, str],
-    },
-    total=False,
-)
-
-
-class CreateRuleGroupsNamespaceRequestRequestTypeDef(
-    _RequiredCreateRuleGroupsNamespaceRequestRequestTypeDef,
-    _OptionalCreateRuleGroupsNamespaceRequestRequestTypeDef,
-):
-    pass
-
 
 CreateRuleGroupsNamespaceResponseTypeDef = TypedDict(
     "CreateRuleGroupsNamespaceResponseTypeDef",
@@ -172,11 +132,10 @@ CreateRuleGroupsNamespaceResponseTypeDef = TypedDict(
 CreateWorkspaceRequestRequestTypeDef = TypedDict(
     "CreateWorkspaceRequestRequestTypeDef",
     {
-        "alias": str,
-        "clientToken": str,
-        "tags": Mapping[str, str],
+        "alias": NotRequired[str],
+        "clientToken": NotRequired[str],
+        "tags": NotRequired[Mapping[str, str]],
     },
-    total=False,
 )
 
 CreateWorkspaceResponseTypeDef = TypedDict(
@@ -190,71 +149,30 @@ CreateWorkspaceResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredDeleteAlertManagerDefinitionRequestRequestTypeDef = TypedDict(
-    "_RequiredDeleteAlertManagerDefinitionRequestRequestTypeDef",
+DeleteAlertManagerDefinitionRequestRequestTypeDef = TypedDict(
+    "DeleteAlertManagerDefinitionRequestRequestTypeDef",
     {
         "workspaceId": str,
+        "clientToken": NotRequired[str],
     },
 )
-_OptionalDeleteAlertManagerDefinitionRequestRequestTypeDef = TypedDict(
-    "_OptionalDeleteAlertManagerDefinitionRequestRequestTypeDef",
-    {
-        "clientToken": str,
-    },
-    total=False,
-)
 
-
-class DeleteAlertManagerDefinitionRequestRequestTypeDef(
-    _RequiredDeleteAlertManagerDefinitionRequestRequestTypeDef,
-    _OptionalDeleteAlertManagerDefinitionRequestRequestTypeDef,
-):
-    pass
-
-
-_RequiredDeleteRuleGroupsNamespaceRequestRequestTypeDef = TypedDict(
-    "_RequiredDeleteRuleGroupsNamespaceRequestRequestTypeDef",
+DeleteRuleGroupsNamespaceRequestRequestTypeDef = TypedDict(
+    "DeleteRuleGroupsNamespaceRequestRequestTypeDef",
     {
         "name": str,
         "workspaceId": str,
+        "clientToken": NotRequired[str],
     },
 )
-_OptionalDeleteRuleGroupsNamespaceRequestRequestTypeDef = TypedDict(
-    "_OptionalDeleteRuleGroupsNamespaceRequestRequestTypeDef",
-    {
-        "clientToken": str,
-    },
-    total=False,
-)
 
-
-class DeleteRuleGroupsNamespaceRequestRequestTypeDef(
-    _RequiredDeleteRuleGroupsNamespaceRequestRequestTypeDef,
-    _OptionalDeleteRuleGroupsNamespaceRequestRequestTypeDef,
-):
-    pass
-
-
-_RequiredDeleteWorkspaceRequestRequestTypeDef = TypedDict(
-    "_RequiredDeleteWorkspaceRequestRequestTypeDef",
+DeleteWorkspaceRequestRequestTypeDef = TypedDict(
+    "DeleteWorkspaceRequestRequestTypeDef",
     {
         "workspaceId": str,
+        "clientToken": NotRequired[str],
     },
 )
-_OptionalDeleteWorkspaceRequestRequestTypeDef = TypedDict(
-    "_OptionalDeleteWorkspaceRequestRequestTypeDef",
-    {
-        "clientToken": str,
-    },
-    total=False,
-)
-
-
-class DeleteWorkspaceRequestRequestTypeDef(
-    _RequiredDeleteWorkspaceRequestRequestTypeDef, _OptionalDeleteWorkspaceRequestRequestTypeDef
-):
-    pass
-
 
 DescribeAlertManagerDefinitionRequestRequestTypeDef = TypedDict(
     "DescribeAlertManagerDefinitionRequestRequestTypeDef",
@@ -302,29 +220,15 @@ DescribeWorkspaceResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListRuleGroupsNamespacesRequestRequestTypeDef = TypedDict(
-    "_RequiredListRuleGroupsNamespacesRequestRequestTypeDef",
+ListRuleGroupsNamespacesRequestRequestTypeDef = TypedDict(
+    "ListRuleGroupsNamespacesRequestRequestTypeDef",
     {
         "workspaceId": str,
+        "maxResults": NotRequired[int],
+        "name": NotRequired[str],
+        "nextToken": NotRequired[str],
     },
 )
-_OptionalListRuleGroupsNamespacesRequestRequestTypeDef = TypedDict(
-    "_OptionalListRuleGroupsNamespacesRequestRequestTypeDef",
-    {
-        "maxResults": int,
-        "name": str,
-        "nextToken": str,
-    },
-    total=False,
-)
-
-
-class ListRuleGroupsNamespacesRequestRequestTypeDef(
-    _RequiredListRuleGroupsNamespacesRequestRequestTypeDef,
-    _OptionalListRuleGroupsNamespacesRequestRequestTypeDef,
-):
-    pass
-
 
 ListRuleGroupsNamespacesResponseTypeDef = TypedDict(
     "ListRuleGroupsNamespacesResponseTypeDef",
@@ -353,11 +257,10 @@ ListTagsForResourceResponseTypeDef = TypedDict(
 ListWorkspacesRequestRequestTypeDef = TypedDict(
     "ListWorkspacesRequestRequestTypeDef",
     {
-        "alias": str,
-        "maxResults": int,
-        "nextToken": str,
+        "alias": NotRequired[str],
+        "maxResults": NotRequired[int],
+        "nextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListWorkspacesResponseTypeDef = TypedDict(
@@ -372,35 +275,20 @@ ListWorkspacesResponseTypeDef = TypedDict(
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
+        "MaxItems": NotRequired[int],
+        "PageSize": NotRequired[int],
+        "StartingToken": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredPutAlertManagerDefinitionRequestRequestTypeDef = TypedDict(
-    "_RequiredPutAlertManagerDefinitionRequestRequestTypeDef",
+PutAlertManagerDefinitionRequestRequestTypeDef = TypedDict(
+    "PutAlertManagerDefinitionRequestRequestTypeDef",
     {
         "data": Union[bytes, IO[bytes], StreamingBody],
         "workspaceId": str,
+        "clientToken": NotRequired[str],
     },
 )
-_OptionalPutAlertManagerDefinitionRequestRequestTypeDef = TypedDict(
-    "_OptionalPutAlertManagerDefinitionRequestRequestTypeDef",
-    {
-        "clientToken": str,
-    },
-    total=False,
-)
-
-
-class PutAlertManagerDefinitionRequestRequestTypeDef(
-    _RequiredPutAlertManagerDefinitionRequestRequestTypeDef,
-    _OptionalPutAlertManagerDefinitionRequestRequestTypeDef,
-):
-    pass
-
 
 PutAlertManagerDefinitionResponseTypeDef = TypedDict(
     "PutAlertManagerDefinitionResponseTypeDef",
@@ -410,29 +298,15 @@ PutAlertManagerDefinitionResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredPutRuleGroupsNamespaceRequestRequestTypeDef = TypedDict(
-    "_RequiredPutRuleGroupsNamespaceRequestRequestTypeDef",
+PutRuleGroupsNamespaceRequestRequestTypeDef = TypedDict(
+    "PutRuleGroupsNamespaceRequestRequestTypeDef",
     {
         "data": Union[bytes, IO[bytes], StreamingBody],
         "name": str,
         "workspaceId": str,
+        "clientToken": NotRequired[str],
     },
 )
-_OptionalPutRuleGroupsNamespaceRequestRequestTypeDef = TypedDict(
-    "_OptionalPutRuleGroupsNamespaceRequestRequestTypeDef",
-    {
-        "clientToken": str,
-    },
-    total=False,
-)
-
-
-class PutRuleGroupsNamespaceRequestRequestTypeDef(
-    _RequiredPutRuleGroupsNamespaceRequestRequestTypeDef,
-    _OptionalPutRuleGroupsNamespaceRequestRequestTypeDef,
-):
-    pass
-
 
 PutRuleGroupsNamespaceResponseTypeDef = TypedDict(
     "PutRuleGroupsNamespaceResponseTypeDef",
@@ -456,8 +330,8 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-_RequiredRuleGroupsNamespaceDescriptionTypeDef = TypedDict(
-    "_RequiredRuleGroupsNamespaceDescriptionTypeDef",
+RuleGroupsNamespaceDescriptionTypeDef = TypedDict(
+    "RuleGroupsNamespaceDescriptionTypeDef",
     {
         "arn": str,
         "createdAt": datetime,
@@ -465,68 +339,29 @@ _RequiredRuleGroupsNamespaceDescriptionTypeDef = TypedDict(
         "modifiedAt": datetime,
         "name": str,
         "status": "RuleGroupsNamespaceStatusTypeDef",
+        "tags": NotRequired[Dict[str, str]],
     },
 )
-_OptionalRuleGroupsNamespaceDescriptionTypeDef = TypedDict(
-    "_OptionalRuleGroupsNamespaceDescriptionTypeDef",
-    {
-        "tags": Dict[str, str],
-    },
-    total=False,
-)
 
-
-class RuleGroupsNamespaceDescriptionTypeDef(
-    _RequiredRuleGroupsNamespaceDescriptionTypeDef, _OptionalRuleGroupsNamespaceDescriptionTypeDef
-):
-    pass
-
-
-_RequiredRuleGroupsNamespaceStatusTypeDef = TypedDict(
-    "_RequiredRuleGroupsNamespaceStatusTypeDef",
+RuleGroupsNamespaceStatusTypeDef = TypedDict(
+    "RuleGroupsNamespaceStatusTypeDef",
     {
         "statusCode": RuleGroupsNamespaceStatusCodeType,
+        "statusReason": NotRequired[str],
     },
 )
-_OptionalRuleGroupsNamespaceStatusTypeDef = TypedDict(
-    "_OptionalRuleGroupsNamespaceStatusTypeDef",
-    {
-        "statusReason": str,
-    },
-    total=False,
-)
 
-
-class RuleGroupsNamespaceStatusTypeDef(
-    _RequiredRuleGroupsNamespaceStatusTypeDef, _OptionalRuleGroupsNamespaceStatusTypeDef
-):
-    pass
-
-
-_RequiredRuleGroupsNamespaceSummaryTypeDef = TypedDict(
-    "_RequiredRuleGroupsNamespaceSummaryTypeDef",
+RuleGroupsNamespaceSummaryTypeDef = TypedDict(
+    "RuleGroupsNamespaceSummaryTypeDef",
     {
         "arn": str,
         "createdAt": datetime,
         "modifiedAt": datetime,
         "name": str,
         "status": "RuleGroupsNamespaceStatusTypeDef",
+        "tags": NotRequired[Dict[str, str]],
     },
 )
-_OptionalRuleGroupsNamespaceSummaryTypeDef = TypedDict(
-    "_OptionalRuleGroupsNamespaceSummaryTypeDef",
-    {
-        "tags": Dict[str, str],
-    },
-    total=False,
-)
-
-
-class RuleGroupsNamespaceSummaryTypeDef(
-    _RequiredRuleGroupsNamespaceSummaryTypeDef, _OptionalRuleGroupsNamespaceSummaryTypeDef
-):
-    pass
-
 
 TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
@@ -544,63 +379,35 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateWorkspaceAliasRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateWorkspaceAliasRequestRequestTypeDef",
+UpdateWorkspaceAliasRequestRequestTypeDef = TypedDict(
+    "UpdateWorkspaceAliasRequestRequestTypeDef",
     {
         "workspaceId": str,
+        "alias": NotRequired[str],
+        "clientToken": NotRequired[str],
     },
 )
-_OptionalUpdateWorkspaceAliasRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateWorkspaceAliasRequestRequestTypeDef",
-    {
-        "alias": str,
-        "clientToken": str,
-    },
-    total=False,
-)
-
-
-class UpdateWorkspaceAliasRequestRequestTypeDef(
-    _RequiredUpdateWorkspaceAliasRequestRequestTypeDef,
-    _OptionalUpdateWorkspaceAliasRequestRequestTypeDef,
-):
-    pass
-
 
 WaiterConfigTypeDef = TypedDict(
     "WaiterConfigTypeDef",
     {
-        "Delay": int,
-        "MaxAttempts": int,
+        "Delay": NotRequired[int],
+        "MaxAttempts": NotRequired[int],
     },
-    total=False,
 )
 
-_RequiredWorkspaceDescriptionTypeDef = TypedDict(
-    "_RequiredWorkspaceDescriptionTypeDef",
+WorkspaceDescriptionTypeDef = TypedDict(
+    "WorkspaceDescriptionTypeDef",
     {
         "arn": str,
         "createdAt": datetime,
         "status": "WorkspaceStatusTypeDef",
         "workspaceId": str,
+        "alias": NotRequired[str],
+        "prometheusEndpoint": NotRequired[str],
+        "tags": NotRequired[Dict[str, str]],
     },
 )
-_OptionalWorkspaceDescriptionTypeDef = TypedDict(
-    "_OptionalWorkspaceDescriptionTypeDef",
-    {
-        "alias": str,
-        "prometheusEndpoint": str,
-        "tags": Dict[str, str],
-    },
-    total=False,
-)
-
-
-class WorkspaceDescriptionTypeDef(
-    _RequiredWorkspaceDescriptionTypeDef, _OptionalWorkspaceDescriptionTypeDef
-):
-    pass
-
 
 WorkspaceStatusTypeDef = TypedDict(
     "WorkspaceStatusTypeDef",
@@ -609,24 +416,14 @@ WorkspaceStatusTypeDef = TypedDict(
     },
 )
 
-_RequiredWorkspaceSummaryTypeDef = TypedDict(
-    "_RequiredWorkspaceSummaryTypeDef",
+WorkspaceSummaryTypeDef = TypedDict(
+    "WorkspaceSummaryTypeDef",
     {
         "arn": str,
         "createdAt": datetime,
         "status": "WorkspaceStatusTypeDef",
         "workspaceId": str,
+        "alias": NotRequired[str],
+        "tags": NotRequired[Dict[str, str]],
     },
 )
-_OptionalWorkspaceSummaryTypeDef = TypedDict(
-    "_OptionalWorkspaceSummaryTypeDef",
-    {
-        "alias": str,
-        "tags": Dict[str, str],
-    },
-    total=False,
-)
-
-
-class WorkspaceSummaryTypeDef(_RequiredWorkspaceSummaryTypeDef, _OptionalWorkspaceSummaryTypeDef):
-    pass
